@@ -29,7 +29,7 @@ import java.io.Reader;
 import org.junit.jupiter.api.Test;
 
 /**
- * JUnit Test Case for {@link NullReader}.
+ * Tests {@link NullReader}.
  */
 public class NullReaderTest {
 
@@ -37,18 +37,21 @@ public class NullReaderTest {
         public TestNullReader(final int size) {
             super(size);
         }
+
         public TestNullReader(final int size, final boolean markSupported, final boolean throwEofException) {
             super(size, markSupported, throwEofException);
         }
+
         @Override
         protected int processChar() {
-            return (int)getPosition() - 1;
+            return (int) getPosition() - 1;
         }
+
         @Override
         protected void processChars(final char[] chars, final int offset, final int length) {
-            final int startPos = (int)getPosition() - length;
+            final int startPos = (int) getPosition() - length;
             for (int i = offset; i < length; i++) {
-                chars[i] = (char)(startPos + i);
+                chars[i] = (char) (startPos + i);
             }
         }
 
@@ -69,25 +72,21 @@ public class NullReaderTest {
     @Test
     public void testMarkAndReset() throws Exception {
         int position = 0;
-        final int readlimit = 10;
+        final int readLimit = 10;
         try (Reader reader = new TestNullReader(100, true, false)) {
 
             assertTrue(reader.markSupported(), "Mark Should be Supported");
 
             // No Mark
-            try {
-                reader.reset();
-                fail("Read limit exceeded, expected IOException ");
-            } catch (final IOException e) {
-                assertEquals("No position has been marked", e.getMessage(), "No Mark IOException message");
-            }
+            final IOException resetException = assertThrows(IOException.class, reader::reset);
+            assertEquals("No position has been marked", resetException.getMessage(), "No Mark IOException message");
 
             for (; position < 3; position++) {
                 assertEquals(position, reader.read(), "Read Before Mark [" + position + "]");
             }
 
             // Mark
-            reader.mark(readlimit);
+            reader.mark(readLimit);
 
             // Read further
             for (int i = 0; i < 3; i++) {
@@ -98,18 +97,14 @@ public class NullReaderTest {
             reader.reset();
 
             // Read From marked position
-            for (int i = 0; i < readlimit + 1; i++) {
+            for (int i = 0; i < readLimit + 1; i++) {
                 assertEquals(position + i, reader.read(), "Read After Reset [" + i + "]");
             }
 
             // Reset after read limit passed
-            try {
-                reader.reset();
-                fail("Read limit exceeded, expected IOException ");
-            } catch (final IOException e) {
-                assertEquals("Marked position [" + position + "] is no longer valid - passed the read limit [" + readlimit + "]", e.getMessage(),
+            final IOException e = assertThrows(IOException.class, reader::reset);
+            assertEquals("Marked position [" + position + "] is no longer valid - passed the read limit [" + readLimit + "]", e.getMessage(),
                     "Read limit IOException message");
-            }
         }
     }
 
@@ -211,12 +206,9 @@ public class NullReaderTest {
             assertEquals(7, reader.read(), "Read 3");
             assertEquals(2, reader.skip(5), "Skip 2"); // only 2 left to skip
             assertEquals(-1, reader.skip(5), "Skip 3 (EOF)"); // End of file
-            try {
-                reader.skip(5); //
-                fail("Expected IOException for skipping after end of file");
-            } catch (final IOException e) {
-                assertEquals("Skip after end of file", e.getMessage(), "Skip after EOF IOException message");
-            }
+
+            final IOException e = assertThrows(IOException.class, () -> reader.skip(5));
+            assertEquals("Skip after end of file", e.getMessage(), "Skip after EOF IOException message");
         }
     }
 }
